@@ -48,7 +48,7 @@ class RTComElEvent(ctypes.Structure):
                 ("fld_pango_markup", ctypes.c_char_p)]
 
 
-def put_to_sent_sms(name, number, uniqueid, groupid, tme, message):
+def put_to_sent_sms(name, number, uniqueid, groupid, tme, message, g):
     rtcom = ctypes.CDLL('librtcom-eventlogger.so.1') # PR 1.2
     #rtcom = ctypes.CDLL('librtcom-eventlogger.so.0') # PR 1.1
 
@@ -59,7 +59,7 @@ def put_to_sent_sms(name, number, uniqueid, groupid, tme, message):
     event.fld_service  = 'RTCOM_EL_SERVICE_SMS'
 
     event._mask       |= 1 << 19
-    event.fld_event_type = 'RTCOM_EL_EVENTTYPE_SMS_OUTBOUND'
+    event.fld_event_type = 'RTCOM_EL_EVENTTYPE_SMS_'+g+'BOUND'
 
     event._mask       |= 1 << 4
     event.fld_start_time = tme
@@ -166,7 +166,7 @@ class EntryDialog( gtk.Dialog):
 
 	self.entry2 = gtk.Entry()
 
-	self.entry2.set_max_length(160)
+        self.entry2.set_max_length(160)
 
 	box.pack_start(self.entry2)
 
@@ -184,6 +184,19 @@ class EntryDialog( gtk.Dialog):
 
         self.entry3.show()
 
+        label = gtk.Label('IN or OUT')
+
+        box.pack_start(label)
+
+        label.show()
+
+	self.entry4 = gtk.Entry()
+
+	box.pack_start(self.entry4)
+
+        self.entry4.show()
+
+
         button = gtk.Button("OK")
 
         button.connect("clicked", self.click)
@@ -225,8 +238,9 @@ class EntryDialog( gtk.Dialog):
 	# grp is last 7 (or fewer) digits/whatever
 	grp = nr[-7:]
 	msg = foo2
-	sendername = "" # do we really need to specify this ourselves? :(
-	put_to_sent_sms(sendername, nr, 0, grp, tm, msg)
+	m=self.entry4.get_text()
+        sendername = "" # do we really need to specify this ourselves? :(
+	put_to_sent_sms(sendername, nr, 0, grp, tm, msg, m)
         
 
 
